@@ -1,4 +1,4 @@
-__version__ = "1.7.1"
+__version__ = "1.7.3"
 
 import logging
 from urllib.parse import urlparse, parse_qs
@@ -42,6 +42,7 @@ class QRonosClient(object):
             'get_attributes': f"{prefix}/attributes/",
             'get_stages': f"{prefix}/stages/",
             'get_stage_history': f"{prefix}/stage_history/",
+            'get_attribute_history': f"{prefix}/attribute_history/",
         }
 
     def _get(self, *args, **kwargs):
@@ -104,7 +105,7 @@ class QRonosClient(object):
                 raise QRonosError("Unable to get Job ID from Import request") from err
         raise QRonosError(f"Bad Import request - {response.content}")
 
-    def tracker_import(self, tracker_id, unique_columns, can_add_item, can_delete_item, data):
+    def tracker_import(self, tracker_id, unique_columns, can_add_item, can_delete_item, data, extra_column_name=None):
         """
         Imports tracker (item) data.
 
@@ -113,17 +114,21 @@ class QRonosClient(object):
         :param can_add_item: Import can add Items?
         :param can_delete_item: Import can delete Items?
         :param data: The import data as a list of dictionaries (keys must match the headers from unique_columns parameter)
+        :param extra_column_name When provided this header will serve as an extra source of data for the items
         :return: Job ID
         """
+        body = {
+            'tracker': tracker_id,
+            'unique_columns': unique_columns,
+            'can_add_item': can_add_item,
+            'can_delete_item': can_delete_item,
+            'data': data,
+        }
+        if extra_column_name:
+            body['extra_column_name'] = extra_column_name
         return self._run_import(
             self.urls['tracker_import'],
-            {
-                'tracker': tracker_id,
-                'unique_columns': unique_columns,
-                'can_add_item': can_add_item,
-                'can_delete_item': can_delete_item,
-                'data': data,
-            }
+            body
         )
 
     def stage_import(self, stage_id=None, tracker_stage_id=None, data=None):
@@ -388,6 +393,20 @@ class QRonosClient(object):
         """
         return self._get_all_item_data(get_data_method=self.get_item_stage_history, **kwargs)
 
+    def get_all_item_attribute_history(self, **kwargs):
+        """
+        Get all item attribute history with a tracker ID with optional unique key(s)
+
+        Keyword arguments:
+        :param tracker: The ID of the Tracker
+        :param unique_keys: A list of unique item keys
+        :param unique_key: A unique item key
+        :param attribute_names: a list of attribute input names
+        :param page_size: Number of retrieved per iteration
+        :return: Item stages history
+        """
+        return self._get_all_item_data(get_data_method=self.get_item_attribute_history, **kwargs)
+
     @staticmethod
     def _get_all_item_data(get_data_method, **kwargs):
         """
@@ -407,3 +426,50 @@ class QRonosClient(object):
             data = get_data_method(page=nextp, **kwargs)
             all_data.extend(data.get('items'))
         return all_data
+
+    def get_item_attribute_history(
+        self,
+        tracker=None,
+        attribute_names=None,
+        unique_keys=None,
+        unique_key=None,
+        page_size=None,
+        page=None,
+    ):
+        """
+        Get item attribute history with a tracker ID with optional unique key(s)
+
+        Keyword arguments:
+        :param tracker: The ID of the Tracker
+        :param attribute_names: A list of attribute input names
+        :param unique_keys: A list of unique item keys
+        :param unique_key: A unique item key
+        :param page_size: Number of retrieved per iteration
+        :param page: The link for next page
+        :return: Item attribute history
+        """
+
+        post_data = {
+            "tracker": tracker,
+            "attribute_names": attribute_names
+        }
+        params = {}
+
+        if unique_keys:
+            post_data["unique_keys"] = unique_keys
+        elif unique_key:
+            post_data["unique_key"] = unique_key
+
+        if page:
+            params.update(parse_qs(urlparse(page).query))
+        if page_size:
+            params['page_size'] = page_size
+
+        response = self._post(self.urls['get_attribute_history'], json=post_data, params=params)
+        if response.status_code == 200:
+            try:
+                return response.json()
+            except Exception as err:
+                raise QRonosError("Unable to get attribute history data") from err
+        else:
+            raise QRonosError(f"QRONOS Error - {response.status_code} - {response.reason}")
